SDK
----

wallaroo
=========
.. automodule:: wallaroo
    :members:
    :undoc-members:

auth
====

.. automodule:: wallaroo.auth
    :members:
    :undoc-members:

client
======

.. automodule:: wallaroo.client
    :members:
    :undoc-members:

checks
======
.. automodule:: wallaroo.checks
    :members:
    :undoc-members:

deployment_config
=================
.. automodule:: wallaroo.deployment_config
    :members:
    :undoc-members:

deployment
==========
.. automodule:: wallaroo.deployment
    :members:
    :undoc-members:

inference_result
================
.. automodule:: wallaroo.inference_result
    :members:
    :undoc-members:

logs
====
.. automodule:: wallaroo.logs
    :members:
    :undoc-members:

model_config
============
.. automodule:: wallaroo.model_config
    :members:
    :undoc-members:

model
=====
.. automodule:: wallaroo.model
    :members:
    :undoc-members:

pipeline_variant
================
.. automodule:: wallaroo.pipeline_variant
    :members:
    :undoc-members:

pipeline
========
.. automodule:: wallaroo.pipeline
    :members:
    :undoc-members:

standalone_client
=================
.. automodule:: wallaroo.standalone_client
    :members:
    :undoc-members:
